##  Frequently Asked Questions
### Why are there tiers with different response times, and why is there a change in scope?
Introducing the vendor tiers with different response times and a clear scope of catalog items allows us to focus on high quality of data and data maintenance. We aim for proactive data maintenance and addition of IT components and applications for provider tier 1 (excluding hardware items), increasing our catalog's significance, relevance, and impact, especially for technology risk management and SAP landscape discovery.
### How are the tiers of providers and response times determined?
The classification is based on the vendor's significance in enterprise architecture as determined by SAP LeanIX.
  * Tier 1 IT component providers are identified by examining software providers with the largest market capitalization. These providers are then ranked according to their revenue, and the top 10 are included in tier 1.
  * The selection of tier 2 IT component providers is guided by the usage analysis of the catalog, specifically the linking of catalog items to fact sheets in live workspaces.


With this approach, we aim to ensure optimal response times, maintenance schedules, and coverage for the top providers in the market
### Will the list of vendor tiers stay as is?
We consider the list stable and do not expect significant changes. Annually, we conduct a review of top software providers and assess the usage of our catalog. Vendors might be added, removed, or moved to a different tier.
### What happens to my requested items that are out of scope?
Such requests will be declined with a comment stating that the item is out of the scope of the catalog.
We are working towards providing clear information on the response time and target dates based on the provider tier in the application soon.
### Why are some of the catalog items named as major.x or major.minor.x?
As part of our ongoing efforts to review and maintain our catalog to ensure high data quality, we are aggregating some catalog items into Major.x or Major.Minor.x versions. This aggregation aligns with the lifecycle policies of the providers and aims to enhance the management of technology obsolescence risk.
### What do I do when I see a catalog item with major.x version?
Catalog items labeled with a Major.x or Major.Minor.x version, like PostgreSQL Global Development Group PostgreSQL 16.x, also serve as a modeling guideline for the product version.
You can also choose to keep multiple versions (for example, 16.2, 16.3, and so on) as individual fact sheets and link them to the same catalog item (16.x).
YesNo
Send
